/// <reference types="react" />
export type UseAudioReturn = {
    play: () => void;
    pause: () => void;
    stop: () => void;
    isPlaying: boolean;
    audioRef: React.MutableRefObject<HTMLAudioElement | null>;
};
export type UseAudioOptions = {
    onPlay?: (value: any) => void;
    onPlaying?: (e: any) => void;
    onPause?: () => void;
    onStop?: () => void;
    onEnd?: (e: any) => void;
};
/**
 * 音频钩子函数，用于管理音频的播放状态和操作
 * @param src 音频文件的URL， 建议使用 `blob url`
 * @param opts 配置选项，包括播放、暂停、停止时的回调函数等
 * @returns 返回包含播放、暂停、停止方法和播放状态的音频钩子对象
 */
declare const useAudio: (src: string, opts?: UseAudioOptions) => UseAudioReturn;
export default useAudio;
