function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import { useMemoizedFn } from 'ahooks';
import { useEffect, useRef, useState } from 'react';
var isBlobUrl = function isBlobUrl(url) {
  return url.startsWith('blob:');
};

/**
 * 音频钩子函数，用于管理音频的播放状态和操作
 * @param src 音频文件的URL， 建议使用 `blob url`
 * @param opts 配置选项，包括播放、暂停、停止时的回调函数等
 * @returns 返回包含播放、暂停、停止方法和播放状态的音频钩子对象
 */
var useAudio = function useAudio(src) {
  var opts = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  // 管理音频的播放状态
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    isPlaying = _useState2[0],
    setIsPlaying = _useState2[1];
  // 用于存储音频元素的引用
  var audioRef = useRef(null);

  /**
   * 播放音频的方法
   * 如果音频元素不存在，则不执行任何操作
   * 尝试播放音频，并在成功播放后更新状态和调用回调函数
   * 如果播放失败，则在控制台输出错误信息
   */
  var play = useMemoizedFn(function () {
    if (!audioRef.current) return;
    audioRef.current.play().then(function (value) {
      var _opts$onPlay;
      setIsPlaying(true);
      opts === null || opts === void 0 ? void 0 : (_opts$onPlay = opts.onPlay) === null || _opts$onPlay === void 0 ? void 0 : _opts$onPlay.call(opts, value);
    }).catch(function (error) {
      console.error('Error playing audio:', error);
    });
  });

  /**
   * 暂停音频的方法
   * 如果音频元素存在且未暂停，则暂停音频并更新状态和调用回调函数
   */
  var pause = useMemoizedFn(function () {
    if (audioRef.current && !audioRef.current.paused) {
      var _opts$onPause;
      audioRef.current.pause();
      setIsPlaying(false);
      opts === null || opts === void 0 ? void 0 : (_opts$onPause = opts.onPause) === null || _opts$onPause === void 0 ? void 0 : _opts$onPause.call(opts);
    }
  });

  /**
   * 停止音频的方法
   * 如果音频元素不存在，则不执行任何操作
   * 停止音频播放，重置音频到开始，并更新状态和调用回调函数
   */
  var stop = useMemoizedFn(function () {
    var _opts$onStop;
    if (!audioRef.current) return;
    audioRef.current.pause();
    audioRef.current.currentTime = 0; // 重置音频到开始
    if (isBlobUrl(audioRef.current.src)) URL.revokeObjectURL(audioRef.current.src);
    setIsPlaying(false);
    opts === null || opts === void 0 ? void 0 : (_opts$onStop = opts.onStop) === null || _opts$onStop === void 0 ? void 0 : _opts$onStop.call(opts);
  });

  /**
   * 处理音频播放中的事件的方法
   * 调用配置选项中的播放中回调函数
   */
  var handlePlaying = useMemoizedFn(function (e) {
    var _opts$onPlaying;
    opts === null || opts === void 0 ? void 0 : (_opts$onPlaying = opts.onPlaying) === null || _opts$onPlaying === void 0 ? void 0 : _opts$onPlaying.call(opts, e);
  });

  /**
   * 处理音频播放结束事件的方法
   * 更新播放状态为false，并调用配置选项中的播放结束回调函数
   */
  var handleEnded = useMemoizedFn(function (e) {
    var _opts$onEnd;
    setIsPlaying(false);
    opts === null || opts === void 0 ? void 0 : (_opts$onEnd = opts.onEnd) === null || _opts$onEnd === void 0 ? void 0 : _opts$onEnd.call(opts, e);
  });

  // 监听音频元素的播放状态变化
  useEffect(function () {
    if (!src) return;
    audioRef.current = new Audio(src);
    // 监听播放中的事件
    audioRef.current.addEventListener('playing', handlePlaying);
    // 监听播放结束事件
    audioRef.current.addEventListener('ended', handleEnded);

    // 清理函数，用于移除事件监听器和释放资源
    return function () {
      if (audioRef.current) {
        var _audioRef$current;
        (_audioRef$current = audioRef.current) === null || _audioRef$current === void 0 ? void 0 : _audioRef$current.pause();
        audioRef.current.currentTime = 0;
        audioRef.current.removeEventListener('playing', handlePlaying);
        audioRef.current.removeEventListener('ended', handleEnded);
        if (isBlobUrl(audioRef.current.src)) URL.revokeObjectURL(audioRef.current.src);
        audioRef.current = null;
      }
    };
  }, [src]);
  return {
    play: play,
    pause: pause,
    stop: stop,
    isPlaying: isPlaying,
    audioRef: audioRef
  };
};
export default useAudio;