import { useEffect } from 'react';

/**
 * 关闭页面时 , 提示用户
 * @param enabled {boolean} 是否开启
 * @param message {string} 自定义退出信息 部分浏览器不能改变
 */
var useBeforeUnload = function useBeforeUnload() {
  var enabled = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
  var message = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '真的要离开吗?';
  useEffect(function () {
    if (!enabled) return;
    var handler = function handler(event) {
      event.preventDefault();
      if (message) {
        event.returnValue = message;
      }
      return message;
    };
    window.addEventListener('beforeunload', handler);
    return function () {
      return window.removeEventListener('beforeunload', handler);
    };
  }, [message, enabled]);
};
export default useBeforeUnload;