import { depsEqual } from "../utils";
import { useEffect, useRef } from 'react';

/**
 * 只在更新时调用并且会深度比较依赖项
 * @param effect{EffectCallback} 更新时所需要调用的函数
 * @param deps{DependencyList}  更新的依赖 (深度比较依赖项)
 */
var useDeepUpdateEffect = function useDeepUpdateEffect(effect, deps) {
  var isMounted = useRef(false);
  var countRef = useRef(0);
  var depsRef = useRef();
  if (deps === void 0 || !depsEqual(deps, depsRef.current)) {
    countRef.current += 1;
    depsRef.current = deps;
  }
  useEffect(function () {
    if (!isMounted.current) {
      isMounted.current = true;
    } else {
      return effect();
    }
  }, [countRef.current]);
};
export default useDeepUpdateEffect;