import type { getTargetElement } from "../utils";
export type Rect = {
    x: number;
    y: number;
    width: number;
    height: number;
    top: number;
    left: number;
    bottom: number;
    right: number;
};
/**
 * 用于测量HTML元素的`尺寸`和`位置`
 *
 * `ahooks` 的 `useSize` 只会返回 width 和 height
 *
 * 它基于Resize Observer API，提供了一种简单的方法来获取元素的实时大小和位置信息
 *
 * @param target 要测量的HTML元素的引用，可以是MutableRefObject类型或者返回HTMLElement的函数
 * @param options 传递给ResizeObserver的选项，用于配置观察行为
 * @returns 返回一个包含元素尺寸和位置信息的矩形对象，以及一个用于停止观察的函数
 */
declare const useMeasure: (target: Parameters<typeof getTargetElement>[0], options?: ResizeObserverOptions) => Rect;
export default useMeasure;
