import { useEffect } from 'react';
export var PageLoadEnum = /*#__PURE__*/function (PageLoadEnum) {
  PageLoadEnum["BACK_FORWAR"] = "back_forward";
  PageLoadEnum["NAVIGATE"] = "navigate";
  PageLoadEnum["RELOAD"] = "reload";
  return PageLoadEnum;
}({});

/**
 * 用于在页面加载时获取页面加载类型
 *
 * @param cb 回调函数，用于处理页面加载类型。参数为 PageLoadEnum 枚举类型，表示页面加载类型。
 */

export default function usePageLoadType(cb) {
  useEffect(function () {
    if (!window.performance || !window.performance.getEntriesByType) {
      console.warn('Performance API not supported');
      return;
    }
    var entries = performance.getEntriesByType('navigation');
    if (entries.length === 0) {
      console.warn('No navigation entries found');
      return;
    }
    var entry = entries[0];
    if (entry && typeof entry.type === 'string' && Object.values(PageLoadEnum).includes(entry.type)) {
      var _type = entry.type;
      if (typeof cb === 'function') {
        cb(_type);
      }
    } else {
      console.warn('Invalid or unsupported navigation type');
    }
  }, [cb]);
}