function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import { cloneDeep } from 'lodash-es';
import { useCallback, useImperativeHandle, useRef, useState } from 'react';

// 定义一个通用的记录类型
/**
 * 通用的记录类型
 * @template T - 记录的类型，默认为 `Record<string, any>`
 */ // 定义 UseShow 的实例类型
/**
 * UseShow 的实例类型
 * @template T - 记录的类型，默认为 `RecordType`
 */
// 定义 UseShow 的配置项类型
/**
 * UseShow 的配置项类型
 * @template T - 记录的类型，默认为 `RecordType`
 */
// 定义 UseShow 的实例引用类型
/**
 * UseShow 的实例引用类型
 * @template T - 记录的类型，默认为 `RecordType`
 */
// 定义 UseShow 的结果类型
/**
 * UseShow 的结果类型
 * @template T - 记录的类型，默认为 `RecordType`
 */
/**
 * 父调用子组件方法，并传值更新状态
 *
 * 此钩子写在子组件中, 父组件通过 ref 调用
 *
 *  - ( 通常用于 Modal 或 Drawer 中 )
 * @template T - 记录的类型，默认为 `RecordType`
 * @param funcRef - 任意名称的 useShow 的实例 `( ref 对象 )`
 * @param [options] - 配置项
 * @returns 父组件调用onShow穿过来的值与传给父组件值的方法
 */
export default function useShow(funcRef) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    open = _useState2[0],
    setOpen = _useState2[1];
  var childrenDataRef = useRef();
  var showRecordRef = useRef();
  var hideRecordRef = useRef();
  var opsOnShow = options.onShow,
    opsOnHide = options.onHide,
    opsShowFormart = options.showFormart,
    opsHideFormart = options.hideFormart;
  useImperativeHandle(funcRef, function () {
    return {
      /**
       * 显示记录
       * @param data - 要显示的记录
       */
      onShow: function onShow(data) {
        var record = showRecordRef.current = cloneDeep(data);
        setOpen(true);
        opsOnShow === null || opsOnShow === void 0 ? void 0 : opsOnShow(record);
      },
      /**
       * 隐藏记录
       * @param data - 要隐藏的记录
       */
      onHide: function onHide(data) {
        var record = hideRecordRef.current = cloneDeep(data);
        setOpen(false);
        opsOnHide === null || opsOnHide === void 0 ? void 0 : opsOnHide(record);
      },
      /**
       * 获取子组件的数据
       * @returns 子组件的数据
       */
      getChildData: function getChildData() {
        return childrenDataRef.current;
      }
    };
  });

  /**
   * 设置父组件的数据
   * @param data - 父组件的数据
   */
  var setParentData = useCallback(function (data) {
    childrenDataRef.current = cloneDeep(data);
  }, []);

  /**
   * 更新打开状态
   * @param o - 打开状态
   */
  var updateOpen = useCallback(function (o) {
    setOpen(o);
  }, []);

  /**
   * 关闭
   */
  var close = useCallback(function () {
    setOpen(false);
  }, []);

  /**
   * 清除数据
   */
  var clear = useCallback(function () {
    childrenDataRef.current = undefined;
    showRecordRef.current = undefined;
    hideRecordRef.current = undefined;
  }, []);
  var showRecord = opsShowFormart ? opsShowFormart(showRecordRef.current) : showRecordRef.current;
  var hideRecord = opsHideFormart ? opsHideFormart(hideRecordRef.current) : hideRecordRef.current;
  return {
    setParentData: setParentData,
    showRecord: showRecord,
    hideRecord: hideRecord,
    open: open,
    updateOpen: updateOpen,
    close: close,
    clear: clear
  };
}