function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import { useLatest, useRafState } from 'ahooks';
import { getTargetElement } from "../utils";
import { useEffect, useLayoutEffect, useRef } from 'react';
/**
 * 用于滑块验证滑动距离的 hook
 * 支持 PC 端、移动端、触摸笔
 * @param {(target: (() => HTMLElement) | React.RefObject<HTMLElement>) => HTMLElement} target 验证滑块的 DOM
 * @param {{
 *     initX?: number;
 *     maxMoveX?: number;
 *     onMouseDown?: (moveX: number) => void;
 *     onMouseMove?: (moveX: number) => void;
 *     onMouseUp?: (moveX: number) => void;
 *   }} options 配置项
 */
export default function useSlideVerify(target) {
  var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
    _ref$initX = _ref.initX,
    initX = _ref$initX === void 0 ? 0 : _ref$initX,
    _ref$maxMoveX = _ref.maxMoveX,
    maxMoveX = _ref$maxMoveX === void 0 ? 400 : _ref$maxMoveX,
    onMouseDown = _ref.onMouseDown,
    onMouseMove = _ref.onMouseMove,
    onMouseUp = _ref.onMouseUp;
  var _useRafState = useRafState(initX),
    _useRafState2 = _slicedToArray(_useRafState, 2),
    dx = _useRafState2[0],
    setDx = _useRafState2[1];
  var _useRafState3 = useRafState(false),
    _useRafState4 = _slicedToArray(_useRafState3, 2),
    moveing = _useRafState4[0],
    setMoveing = _useRafState4[1];
  var dxRef = useLatest(dx);
  var moveingRef = useLatest(moveing);
  var initXRef = useRef(initX);
  var reset = function reset() {
    setDx(initX);
    initXRef.current = initX;
  };
  useLayoutEffect(function () {
    var dom = getTargetElement(target);
    if (!dom) return;
    dom.style.transform = "translate3d(".concat(dx, "px, 0, 0)");
    dom.style.transition = moveing ? 'none' : 'transform 0.3s';
  }, [dx, moveing]);
  useEffect(function () {
    var dom = getTargetElement(target);
    if (!dom) return;
    dom.style.touchAction = 'none';
    dom.style.userSelect = 'none';
    dom.style.cursor = 'move';
    var handlePointerDown = function handlePointerDown(e) {
      e.preventDefault();
      dom.setPointerCapture(e.pointerId);
      var startX = e.pageX - initXRef.current;
      onMouseDown === null || onMouseDown === void 0 ? void 0 : onMouseDown(startX);
      setMoveing(true);
      var handlePointerMove = function handlePointerMove(ev) {
        ev.preventDefault();
        if (!moveingRef.current) return;
        var newDx = ev.pageX - startX;
        if (newDx < 0) {
          newDx = 0;
        }
        if (newDx > maxMoveX) {
          newDx = maxMoveX;
        }
        onMouseMove === null || onMouseMove === void 0 ? void 0 : onMouseMove(newDx);
        setDx(newDx);
      };
      var handlePointerUp = function handlePointerUp(evo) {
        evo.preventDefault();
        initXRef.current = dxRef.current;
        setMoveing(false);
        onMouseUp === null || onMouseUp === void 0 ? void 0 : onMouseUp(dxRef.current);
        dom.removeEventListener('pointermove', handlePointerMove);
        dom.removeEventListener('pointerup', handlePointerUp);
      };
      dom.addEventListener('pointermove', handlePointerMove);
      dom.addEventListener('pointerup', handlePointerUp, {
        once: true
      });
    };
    dom.addEventListener('pointerdown', handlePointerDown);
    return function () {
      dom.removeEventListener('pointerdown', handlePointerDown);
    };
  }, []);
  return {
    moveX: dx,
    reset: reset,
    moveing: moveing
  };
}